@@ -58,7 +58,8 @@ ctrAboutPrefs = {
 	  observer.observe(document.querySelector('#categories'), { attributes: true, attributeFilter: ['last-selected'] });
 	  
 	  /* advanced prefs area */
-	  setTimeout(function(){
+	  window.addEventListener("DOMContentLoaded", function aboutprefsIndex(event){
+		window.removeEventListener("DOMContentLoaded", aboutprefsIndex, false);
 		  try{
 			document.getElementById("advancedPrefs").selectedIndex = Services.prefs.getBranch('extensions.classicthemerestorer.').getIntPref('aboutprefsInd');
 		  } catch(e) {}
@@ -74,40 +75,53 @@ ctrAboutPrefs = {
 		  });
 
 		  observer2.observe(document.querySelector('#advancedPrefs'), { attributes: true, attributeFilter: ['selectedIndex'] });
-		  
-	  },500);
+	  },false);
 	  
 	}
-	
-	try{
-	  var thirdpartytheme = Services.prefs.getBranch("general.skins.").getCharPref("selectedSkin");
-	  document.querySelector('#categories').setAttribute('currenttheme',thirdpartytheme);
-	} catch(e){}
-	
-	/* restore favicon wheel for all categories */
-	setTimeout(function(){
-		var windowsService = Components.classes['@mozilla.org/appshell/window-mediator;1'].getService(Components.interfaces.nsIWindowMediator);
-		var currentWindow = windowsService.getMostRecentWindow('navigator:browser');
-		var browser = currentWindow.getBrowser();
-	
-		if(browser.contentDocument.location.href.indexOf('about:preferences')!=-1) {
-		
-			var ss =  Cc["@mozilla.org/content/style-sheet-service;1"].getService(Ci.nsIStyleSheetService);
-			var uri = Services.io.newURI("data:text/css;charset=utf-8," + encodeURIComponent('\
-			\
-			#TabsToolbar .tabbrowser-tab[label="'+browser.selectedTab.label+'"] .tab-icon-image:not([src]),\
-			#main-window[fx44plus="true"] #TabsToolbar .tabbrowser-tab[label="'+browser.selectedTab.label+'"] .tab-icon-image:not([src]),\
-			#TabsToolbar .tabbrowser-tab[label="'+browser.selectedTab.label+'"]:not([pinned]) .tab-icon-image:not([src]),\
-			#main-window[fx44plus="true"] #TabsToolbar .tabbrowser-tab[label="'+browser.selectedTab.label+'"]:not([pinned]) .tab-icon-image:not([src]) {\
-			  list-style-image: url("chrome://browser/skin/preferences/in-content/favicon.ico") !important;\
-			  display:block !important;\
-			}\
-			\
-			'), null, null);
 
-			ss.loadAndRegisterSheet(uri, ss.AGENT_SHEET);
-		}
-	},400);
+	window.addEventListener("DOMContentLoaded", function addPrefAttributes(event){
+	  window.removeEventListener("DOMContentLoaded", addPrefAttributes, false);
+	  setTimeout(function(){
+	
+	  /* add attributes to nodes for better css parting */
+	  try{
+		var thirdpartytheme = Services.prefs.getBranch("general.skins.").getCharPref("selectedSkin");
+		document.querySelector('#categories').setAttribute('currenttheme',thirdpartytheme);
+	  } catch(e){}
+		
+	  try{
+		if(parseInt(Services.appinfo.version) >=46 && parseInt(Services.appinfo.version) < 49)
+		  document.querySelector('#mainPrefPane').setAttribute('fx46plus',true);
+		else if(parseInt(Services.appinfo.version) >=49)
+		  document.querySelector('#mainPrefPane').setAttribute('fx49plus',true);
+	  } catch(e){}
+
+	  /* restore favicon wheel for all categories */
+	  var windowsService = Components.classes['@mozilla.org/appshell/window-mediator;1'].getService(Components.interfaces.nsIWindowMediator);
+	  var currentWindow = windowsService.getMostRecentWindow('navigator:browser');
+	  var browser = currentWindow.getBrowser();
+	
+	  if(browser.contentDocument.location.href.indexOf('about:preferences')!=-1) {
+		
+		var ss =  Cc["@mozilla.org/content/style-sheet-service;1"].getService(Ci.nsIStyleSheetService);
+		var uri = Services.io.newURI("data:text/css;charset=utf-8," + encodeURIComponent('\
+		\
+		#TabsToolbar .tabbrowser-tab[label="'+browser.selectedTab.label+'"] .tab-icon-image:not([src]),\
+		#main-window[fx44plus="true"] #TabsToolbar .tabbrowser-tab[label="'+browser.selectedTab.label+'"] .tab-icon-image:not([src]),\
+		#TabsToolbar .tabbrowser-tab[label="'+browser.selectedTab.label+'"]:not([pinned]) .tab-icon-image:not([src]),\
+		#main-window[fx44plus="true"] #TabsToolbar .tabbrowser-tab[label="'+browser.selectedTab.label+'"]:not([pinned]) .tab-icon-image:not([src]) {\
+		  list-style-image: url("chrome://browser/skin/preferences/in-content/favicon.ico") !important;\
+		  display:block !important;\
+		}\
+		\
+		'), null, null);
+		
+		console.log(browser.selectedTab.label);
+
+		ss.loadAndRegisterSheet(uri, ss.AGENT_SHEET);
+	  }
+	  },500);
+	},false);
 	
   }
 }
