@@ -67,7 +67,6 @@ classicthemerestorerjso.ctr = {
 		document.getElementById('ctraddon_abhigher').disabled = true;
 		document.getElementById('ctraddon_pw_smallnavbut').disabled = true;
 		document.getElementById('ctraddon_pw_iconsbig').disabled = true;
-		document.getElementById('ctraddon_pw_bfurlbarfix').disabled = true;
 		document.getElementById('ctraddon_pw_altmenubar').disabled = true;
 		document.getElementById('ctraddon_pw_menubarnofog').disabled = true;
 		document.getElementById('ctraddon_pw_tabmokcolor').disabled = true;
@@ -104,7 +103,6 @@ classicthemerestorerjso.ctr = {
 		document.getElementById('ctraddon_pw_ccol_act_b1').style.visibility = 'collapse';
 		document.getElementById('ctraddon_pw_ccol_act_b2').style.visibility = 'collapse';
 
-		document.getElementById('ctraddon_pw_bfurlbarfix').style.visibility = 'collapse';
 		document.getElementById('ctraddon_pw_altmenubar').style.visibility = 'collapse';
 		document.getElementById('ctraddon_pw_menubarnofog').style.visibility = 'collapse';
 		document.getElementById('ctraddon_pw_tabmokcolor').style.visibility = 'collapse';
@@ -517,9 +515,11 @@ classicthemerestorerjso.ctr = {
 	this.ctrpwTranspTbW10(this.prefs.getBoolPref("transpttbw10"));
 	this.ctrpwNavBarPadding(this.prefs.getBoolPref("navbarpad"));
 	this.ctrpwLocationSearchbarSize(this.prefs.getBoolPref("lbsbsize"));
+	this.ctrpwLocationSearchbarRadius(this.prefs.getBoolPref("lbsbradius"));
 	this.ctrpwCompactAddonList(this.prefs.getBoolPref("am_compact"));
 	this.ctrpwUnsortBM(this.prefs.getBoolPref("bmbunsortbm"));
 	this.ctrpwHideUrlStopRel(this.prefs.getBoolPref("hideurelstop"));
+	this.ctrpwExtraUrlbar(this.prefs.getBoolPref("extraurlkeycb"));
 	
 	var closetab_value = this.prefs.getCharPref("closetab");
   
@@ -745,11 +745,28 @@ classicthemerestorerjso.ctr = {
 	}
 	
     document.getElementById('ctraddon_pw_lbsbsize_lb').disabled = which;
-	document.getElementById('ctraddon_pw_lbsbsize_lb').style.visibility = itemvis;
     document.getElementById('ctraddon_pw_lbsbsize_sb').disabled = which;
-	document.getElementById('ctraddon_pw_lbsbsize_sb').style.visibility = itemvis;
-	document.getElementById('ctraddon_lbsbsizelabel1').style.visibility = itemvis;
-	document.getElementById('ctraddon_lbsbsizelabel2').style.visibility = itemvis;
+	document.getElementById('ctraddon_lbsize_minw').disabled = which;
+	document.getElementById('ctraddon_lbsize_maxw').disabled = which;
+	document.getElementById('ctraddon_sbsize_minw').disabled = which;
+	document.getElementById('ctraddon_sbsize_maxw').disabled = which;
+  },
+  
+  ctrpwLocationSearchbarRadius: function(which) {
+	var itemvis = 'collapse';
+	
+    if(which==true) {
+	  which=false; itemvis = 'visible';
+	} else {
+	  which=true; itemvis = 'collapse';
+	}
+	
+    document.getElementById('ctraddon_pw_lbsbradius_lb').disabled = which;
+    document.getElementById('ctraddon_pw_lbsbradius_sb').disabled = which;
+	document.getElementById('ctraddon_lbradius_left').disabled = which;
+	document.getElementById('ctraddon_lbradius_right').disabled = which;
+	document.getElementById('ctraddon_sbradius_left').disabled = which;
+	document.getElementById('ctraddon_sbradius_right').disabled = which;
   },
   
   ctrpwCompactAddonList: function(which) {
@@ -790,6 +807,19 @@ classicthemerestorerjso.ctr = {
     document.getElementById('ctraddon_pw_hideurelstop2').disabled = which;
 	document.getElementById('ctraddon_pw_hideurelstop2').style.visibility = itemvis;
   },
+  
+  ctrpwExtraUrlbar: function(which) {
+	var itemvis = 'collapse';
+	
+    if(which==true) {
+	  which=false; itemvis = 'visible';
+	} else {
+	  which=true; itemvis = 'collapse';
+	}
+	
+    document.getElementById('ctraddon_extraurltarget_list').disabled = which;
+	document.getElementById('ctraddon_extraurltarget_list').style.visibility = itemvis;
+  },
  
   ctrpwCtrOldSearch: function(which) {
 	var itemvis = 'collapse';
@@ -801,13 +831,10 @@ classicthemerestorerjso.ctr = {
 	}
 	
     document.getElementById('ctraddon_pw_ctroldsearchc').disabled = which;
-	document.getElementById('ctraddon_pw_ctroldsearchc').style.visibility = itemvis;
     document.getElementById('ctraddon_pw_osearch_dm').disabled = which;
-	document.getElementById('ctraddon_pw_osearch_dm').style.visibility = itemvis;
-    document.getElementById('ctraddon_pw_search_oit').disabled = which;
-	document.getElementById('ctraddon_pw_search_oit').style.visibility = itemvis;
+    document.getElementById('ctraddon_pw_osearch_iwidth').disabled = which;
     document.getElementById('ctraddon_pw_osearch_meoit').disabled = which;
-	document.getElementById('ctraddon_pw_osearch_meoit').style.visibility = itemvis;
+	document.getElementById('ctraddon_pw_osearch_iwidth').disabled = which;
 	
   },
  
